@@ -273,7 +273,7 @@ class API(object):
         request = HTTPRequest(
             self.endpoint, max_retries=max_retries, verbose=verbose)
         request.set_authorization(self.token_type, self.access_token)
-        result = request.get('/user', params=params, timeout=timeout)
+        result = request.get('/profile', params=params, timeout=timeout)
         return models.Model(result)
 
     def get_variants(self, biosample_id, rsids, **params):
@@ -305,6 +305,50 @@ class API(object):
             data.append(models.Model(item))
         return data
 
+    def professional_variant(self, biosample_id, only_variant_site=True,
+                             regions=None, bed_file=None):
+        """专业级变异数据接口
+        
+        regions 与 bed_file 须且提供其中之一
+        
+        Args:
+            biosample_id(str): 生物样品编号；
+            only_variant_site(bool): 是否仅输出变异位置，默认为True；
+            regions(list): 需要抽取区域的坐标数据，数组长度不得超过5000；
+            bed_file(str): 需要抽取区域的 bed 文件路径，文件须为 zip 压缩文件
+                           且内容不得超过 100w 行
+        """
+        timeout = self.timeout
+        verbose = self.verbose
+        max_retries = self.max_retries
+        if regions is not None and bed_file is not None:
+            raise BGEError(
+                'Regions and bed_file needs to provided one of them.')
+        if regions is None and bed_file is None:
+            raise BGEError(
+                'Regions and bed_file cannot be provided at the same time.')
+        if biosample_id:
+            biosample_id = biosample_id.upper()
+        data = {}
+        data['biosample_id'] = biosample_id
+        data['only_variant_site'] = only_variant_site
+        if regions is not None:
+            if not isinstance(regions, list):
+                raise BGEError(
+                    'Regions parameter type is array')
+            data['regions'] = json.dumps(regions)
+            files = None
+        else:
+            files = {
+                'bed_file': open(str(bed_file), 'rb')
+            }
+        request = HTTPRequest(
+            self.endpoint, max_retries=max_retries, verbose=verbose)
+        request.set_authorization(self.token_type, self.access_token)
+        result = request.post(
+            '/professional/variant', data=data, files=files, timeout=timeout)
+        return models.Model(result)
+
     def get_samples(self, biosample_ids=None, biosample_sites=None,
                     omics=None, project_ids=None, organisms=None,
                     data_availability=None, statuses=None,
